@@ -15,37 +15,40 @@
         <translation>Verze %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="24"/>
         <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
-        <translation>Toto je vývojová verze, neočekávejte plnou funkčnost.</translation>
+        <translation type="obsolete">Toto je vývojová verze, neočekávejte plnou funkčnost.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="25"/>
+        <location filename="../src/AboutView.cpp" line="28"/>
         <source>Report bugs and send in your ideas to %1</source>
         <translation>Hlaste chyby a posílejte své nápady na %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="28"/>
+        <location filename="../src/AboutView.cpp" line="24"/>
         <source>%1 is Free Software but its development takes precious time.</source>
-        <translation>%1 je svobodný software, ale jeho vývoj stoji drahocenný čas.</translation>
+        <translation>%1 je svobodný software, ale jeho vývoj stojí drahocenný čas.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="29"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
-        <translation>Prosím &lt;a href=&apos;%1&apos;&gt;přispějte přes PayPal&lt;/a&gt; a podpořte další vývoj aplikace %2.</translation>
+        <translation type="obsolete">Prosím &lt;a href=&apos;%1&apos;&gt;přispějte přes PayPal&lt;/a&gt; a podpořte další vývoj aplikace %2.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="33"/>
+        <location filename="../src/AboutView.cpp" line="25"/>
+        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
+        <translation>Prosím &lt;a href=&apos;%1&apos;&gt;přispějte&lt;/a&gt; na další vývoj %2.</translation>
+    </message>
+    <message>
+        <location filename="../src/AboutView.cpp" line="32"/>
         <source>Icon designed by %1.</source>
         <translation>Autor ikony: %1.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="34"/>
+        <location filename="../src/AboutView.cpp" line="33"/>
         <source>Compact mode contributed by %1.</source>
         <translation>Autor kompaktního módu: %1.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="35"/>
+        <location filename="../src/AboutView.cpp" line="34"/>
         <source>HTTP proxy support contributed by %1.</source>
         <translation>Autor podpory HTTP proxy: %1.</translation>
     </message>
@@ -54,17 +57,17 @@
         <translation type="obsolete">Verzi pro Windows sestavil: %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="38"/>
+        <location filename="../src/AboutView.cpp" line="37"/>
         <source>Translated by %1</source>
         <translation>Přeložili: %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="57"/>
+        <location filename="../src/AboutView.cpp" line="63"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Vydáno pod &lt;a href=&apos;%1&apos;&gt;licencí GNU General Public License&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="68"/>
+        <location filename="../src/AboutView.cpp" line="74"/>
         <source>&amp;Close</source>
         <translation>&amp;Zavřít</translation>
     </message>
@@ -121,266 +124,307 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="72"/>
         <source>&amp;Back</source>
-        <translation>&amp;Zpět</translation>
+        <translation type="obsolete">&amp;Zpět</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="75"/>
         <source>Go to the previous view</source>
-        <translation>Vrátit se k předchozí obrazovce</translation>
+        <translation type="obsolete">Vrátit se k předchozí obrazovce</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="79"/>
+        <location filename="../src/MainWindow.cpp" line="81"/>
         <source>&amp;Stop</source>
         <translation>&amp;Stop</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="80"/>
+        <location filename="../src/MainWindow.cpp" line="82"/>
         <source>Stop playback and go back to the search view</source>
-        <translation>Zastavit přehrávání a vrátit se zpět na vyhledávání</translation>
+        <translation>Zastaví přehrávání a vrátí se zpět na vyhledávání</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="85"/>
+        <location filename="../src/MainWindow.cpp" line="87"/>
         <source>S&amp;kip</source>
         <translation>Př&amp;eskočit</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="86"/>
+        <location filename="../src/MainWindow.cpp" line="88"/>
         <source>Skip to the next video</source>
-        <translation>Přeskočit na další video</translation>
+        <translation>Přeskočí na další video</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="92"/>
-        <location filename="../src/MainWindow.cpp" line="524"/>
+        <location filename="../src/MainWindow.cpp" line="94"/>
+        <location filename="../src/MainWindow.cpp" line="535"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pauza</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="93"/>
-        <location filename="../src/MainWindow.cpp" line="525"/>
+        <location filename="../src/MainWindow.cpp" line="95"/>
+        <location filename="../src/MainWindow.cpp" line="536"/>
         <source>Pause playback</source>
-        <translation>Pozastavit přehrávání</translation>
+        <translation>Pozastaví přehrávání</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="99"/>
-        <location filename="../src/MainWindow.cpp" line="568"/>
+        <location filename="../src/MainWindow.cpp" line="101"/>
+        <location filename="../src/MainWindow.cpp" line="614"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;Celá obrazovka</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="100"/>
+        <location filename="../src/MainWindow.cpp" line="102"/>
         <source>Go full screen</source>
-        <translation>Přepnout na celou obrazovku</translation>
+        <translation>Přepne na celou obrazovku</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="106"/>
+        <location filename="../src/MainWindow.cpp" line="108"/>
         <source>&amp;Compact mode</source>
         <translation>&amp;Kompaktní mód</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="107"/>
+        <location filename="../src/MainWindow.cpp" line="109"/>
         <source>Hide the playlist and the toolbar</source>
-        <translation>Skrýt playlist a toolbar</translation>
+        <translation>Skryje playlist a toolbar</translation>
+    </message>
+    <message>
+        <source>&amp;YouTube</source>
+        <translation type="obsolete">&amp;YouTube</translation>
+    </message>
+    <message>
+        <source>Open the YouTube video page</source>
+        <translation type="obsolete">Otevřít video na YouTube</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="117"/>
+        <source>Open the &amp;YouTube page</source>
+        <translation>Otevřít stránku &amp;YouTube</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="118"/>
+        <source>Go to the YouTube video page and pause playback</source>
+        <translation>Otevře video na webu YouTube a pozastaví přehrávání</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="124"/>
+        <source>Copy the YouTube &amp;link</source>
+        <translation>Zkopírovat &amp;odkaz na YouTube</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="125"/>
-        <source>&amp;YouTube</source>
-        <translation>&amp;YouTube</translation>
+        <source>Copy the current video YouTube link to the clipboard</source>
+        <translation>Zkopíruje adresu videa na YouTube do schránky</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="126"/>
-        <source>Open the YouTube video page</source>
-        <translation>Otevřít video na YouTube</translation>
+        <location filename="../src/MainWindow.cpp" line="131"/>
+        <source>Copy the video stream &amp;URL</source>
+        <translation>Zkopírovat adresu &amp;video streamu</translation>
     </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="132"/>
+        <source>Copy the current video stream URL to the clipboard</source>
+        <translation>Zkopíruje do schránky adresu video streamu</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="138"/>
         <source>&amp;Remove</source>
         <translation>&amp;Odstranit</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="133"/>
+        <location filename="../src/MainWindow.cpp" line="139"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Odstraní vybraná videa z playlistu</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="139"/>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Move &amp;Up</source>
         <translation>&amp;Nahoru</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="140"/>
+        <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Posune vybraná videa výš v playlistu</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="146"/>
+        <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Move &amp;Down</source>
         <translation>&amp;Dolů</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="147"/>
+        <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Posune vybraná videa níž v playlistu</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="153"/>
+        <location filename="../src/MainWindow.cpp" line="159"/>
         <source>&amp;Clear recent keywords</source>
         <translation>&amp;Vymazat hledané výrazy</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="160"/>
+        <location filename="../src/MainWindow.cpp" line="164"/>
+        <source>Clear the search history. Cannot be undone.</source>
+        <translation>Vyprázdní historii vyhledávání. Akci nelze vrátit.</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="169"/>
         <source>&amp;Quit</source>
         <translation>&amp;Zavřít</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="162"/>
+        <location filename="../src/MainWindow.cpp" line="171"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="163"/>
+        <location filename="../src/MainWindow.cpp" line="172"/>
         <source>Bye</source>
         <translation>Sbohem</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="167"/>
+        <location filename="../src/MainWindow.cpp" line="176"/>
         <source>&amp;Website</source>
         <translation>&amp;Homepage</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="169"/>
+        <location filename="../src/MainWindow.cpp" line="178"/>
         <source>%1 on the Web</source>
         <translation>%1 na Webu</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="173"/>
+        <location filename="../src/MainWindow.cpp" line="182"/>
+        <source>Make a &amp;donation</source>
+        <translation>&amp;Podpořit</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="772"/>
+        <source>Maximum video definition set to %1</source>
+        <translation>Maximální rozlišení videa je %1</translation>
+    </message>
+    <message>
         <source>&amp;Donate via PayPal</source>
-        <translation>&amp;Podpořte přes PayPal</translation>
+        <translation type="obsolete">&amp;Podpořte přes PayPal</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="174"/>
+        <location filename="../src/MainWindow.cpp" line="183"/>
         <source>Please support the continued development of %1</source>
-        <translation>Prosím podpořte další vývoj aplikace %1</translation>
+        <translation>Prosím přispějte na další vývoj aplikace %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="178"/>
+        <location filename="../src/MainWindow.cpp" line="187"/>
         <source>&amp;About</source>
         <translation>&amp;O aplikaci</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="180"/>
+        <location filename="../src/MainWindow.cpp" line="189"/>
         <source>Info about %1</source>
         <translation>Info o aplikaci %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="188"/>
+        <location filename="../src/MainWindow.cpp" line="197"/>
         <source>Search</source>
         <translation>Hledat</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="206"/>
+        <location filename="../src/MainWindow.cpp" line="216"/>
         <source>Mute volume</source>
         <translation>Ztlumit</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="207"/>
+        <location filename="../src/MainWindow.cpp" line="218"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+M</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="782"/>
         <source>High Definition video is enabled</source>
-        <translation>HD video je povolené</translation>
+        <translation type="obsolete">HD video je povolené</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="784"/>
         <source>High Definition video is not enabled</source>
-        <translation>HD video není povolené</translation>
+        <translation type="obsolete">HD video není povolené</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="795"/>
         <source>The current video is in High Definition</source>
-        <translation>Aktuální video je v HD</translation>
+        <translation type="obsolete">Aktuální video je v HD</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="798"/>
         <source>The current video is not in High Definition</source>
-        <translation>Aktuální video není v HD</translation>
+        <translation type="obsolete">Aktuální video není v HD</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="254"/>
+        <location filename="../src/MainWindow.cpp" line="812"/>
+        <source>Your privacy is now safe</source>
+        <translation>Vaše soukromí je nyní v bezpečí</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="268"/>
         <source>&amp;Application</source>
         <translation>&amp;Aplikace</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="263"/>
+        <location filename="../src/MainWindow.cpp" line="276"/>
         <source>&amp;Playlist</source>
         <translation>&amp;Playlist</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="270"/>
+        <location filename="../src/MainWindow.cpp" line="283"/>
         <source>&amp;Video</source>
         <translation>&amp;Video</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="283"/>
+        <location filename="../src/MainWindow.cpp" line="296"/>
         <source>&amp;Help</source>
         <translation>&amp;Nápověda</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="324"/>
+        <location filename="../src/MainWindow.cpp" line="352"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
         <translation>Stiskněte %1 pro zvýšení hlasitosti; %2 pro snížení</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="465"/>
-        <location filename="../src/MainWindow.cpp" line="471"/>
+        <location filename="../src/MainWindow.cpp" line="476"/>
+        <location filename="../src/MainWindow.cpp" line="482"/>
         <source>Opening %1</source>
         <translation>Otevírám %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="515"/>
+        <location filename="../src/MainWindow.cpp" line="526"/>
         <source>Fatal error: %1</source>
         <translation>Chyba: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="517"/>
+        <location filename="../src/MainWindow.cpp" line="528"/>
         <source>Error: %1</source>
         <translation>Chyba: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="538"/>
+        <location filename="../src/MainWindow.cpp" line="549"/>
         <source>&amp;Play</source>
         <translation>&amp;Play</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="539"/>
+        <location filename="../src/MainWindow.cpp" line="550"/>
         <source>Resume playback</source>
         <translation>Pokračovat v přehrávání</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="577"/>
+        <location filename="../src/MainWindow.cpp" line="627"/>
         <source>Exit &amp;Full Screen</source>
         <translation>Vypnout &amp;fullscreen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="674"/>
+        <location filename="../src/MainWindow.cpp" line="710"/>
         <source>Remaining time: %1</source>
         <translation>Zbývající čas: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="720"/>
+        <location filename="../src/MainWindow.cpp" line="756"/>
         <source>Volume at %1%</source>
         <translation>Hlasitost na %1%</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="725"/>
+        <location filename="../src/MainWindow.cpp" line="762"/>
         <source>Volume is muted</source>
         <translation>Zvuk je ztlumen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="727"/>
+        <location filename="../src/MainWindow.cpp" line="765"/>
         <source>Volume is unmuted</source>
         <translation>Zvuk je zapnut</translation>
     </message>
@@ -388,20 +432,55 @@
 <context>
     <name>MediaView</name>
     <message>
-        <location filename="../src/MediaView.cpp" line="25"/>
+        <location filename="../src/MediaView.cpp" line="30"/>
         <source>Most relevant</source>
         <translation>Nalezená videa</translation>
     </message>
     <message>
-        <location filename="../src/MediaView.cpp" line="32"/>
+        <location filename="../src/MediaView.cpp" line="37"/>
         <source>Most recent</source>
         <translation>Nejnovější</translation>
     </message>
     <message>
-        <location filename="../src/MediaView.cpp" line="39"/>
+        <location filename="../src/MediaView.cpp" line="44"/>
         <source>Most viewed</source>
         <translation>Nejsledovanější</translation>
     </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="357"/>
+        <source>You can now paste the YouTube link into another application</source>
+        <translation>Nyní můžete vložit odkaz na video na YouTube do jiného programu</translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="365"/>
+        <source>You can now paste the video stream URL into another application</source>
+        <translation>Nyní můžete vložit odkaz na video stream do jiné aplikace</translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="366"/>
+        <source>The link will be valid only for a limited time.</source>
+        <translation>Tento odkaz platí jen po omezenou dobu.</translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="449"/>
+        <source>This is just the demo version of %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="450"/>
+        <source>It allows you to test the application and see if it works for you.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="454"/>
+        <source>Continue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="455"/>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/MediaView.h" line="31"/>
         <source>You&apos;re watching &quot;%1&quot;</source>
@@ -411,7 +490,7 @@
 <context>
     <name>NetworkAccess</name>
     <message>
-        <location filename="../src/networkaccess.cpp" line="188"/>
+        <location filename="../src/networkaccess.cpp" line="192"/>
         <source>Network error: %1</source>
         <translation>Chyba připojení: %1</translation>
     </message>
@@ -435,32 +514,32 @@
 <context>
     <name>SearchView</name>
     <message>
-        <location filename="../src/SearchView.cpp" line="52"/>
+        <location filename="../src/SearchView.cpp" line="46"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Vítejte v &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="61"/>
+        <location filename="../src/SearchView.cpp" line="55"/>
         <source>Enter a keyword to start watching videos.</source>
         <translation>Zadejte klíčové slovo pro vyhledávání videí.</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="81"/>
+        <location filename="../src/SearchView.cpp" line="75"/>
         <source>Watch</source>
         <translation>Sledovat</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="97"/>
+        <location filename="../src/SearchView.cpp" line="91"/>
         <source>Recent keywords</source>
         <translation>Poslední klíčová slova</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="208"/>
+        <location filename="../src/SearchView.cpp" line="186"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
         <translation>Nová verze aplikace %1 je dostupná. Prosím &lt;a href=&apos;%2&apos;&gt;aktualizujte na verzi %3&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.h" line="28"/>
+        <location filename="../src/SearchView.h" line="29"/>
         <source>Make yourself comfortable</source>
         <translation>Udělejte si pohodlí</translation>
     </message>
@@ -468,9 +547,8 @@
 <context>
     <name>SettingsView</name>
     <message>
-        <location filename="../src/SettingsView.h" line="17"/>
         <source>Preferences</source>
-        <translation>Nastavení</translation>
+        <translation type="obsolete">Nastavení</translation>
     </message>
     <message>
         <source>&amp;Video options</source>
@@ -496,7 +574,7 @@
 <context>
     <name>Video</name>
     <message>
-        <location filename="../src/video.cpp" line="139"/>
+        <location filename="../src/video.cpp" line="145"/>
         <source>Network error: %1 for %2</source>
         <translation>Chyba přípojení: %1 pro %2</translation>
     </message>
