@@ -15,37 +15,40 @@
         <translation>Version %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="24"/>
         <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
-        <translation>Dies ist eine &quot;Technology Vorschau&quot;, erwarte nicht, dass sie perfekt ist.</translation>
+        <translation type="obsolete">Dies ist eine &quot;Technology Vorschau&quot;, erwarte nicht, dass sie perfekt ist.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="25"/>
+        <location filename="../src/AboutView.cpp" line="28"/>
         <source>Report bugs and send in your ideas to %1</source>
         <translation>Bitte berichte Fehler und sende Deine Ideen an %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="28"/>
+        <location filename="../src/AboutView.cpp" line="24"/>
         <source>%1 is Free Software but its development takes precious time.</source>
         <translation>%1 ist freie Software, aber die Entwicklung kostet wertvolle Zeit.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="29"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
-        <translation>Bitte &lt;a href=&apos;%1&apos;&gt;spende via PayPal&lt;/a&gt; um die dauerhafte Entwicklung von %2 zu unterstützen.</translation>
+        <translation type="obsolete">Bitte &lt;a href=&apos;%1&apos;&gt;spende via PayPal&lt;/a&gt; um die dauerhafte Entwicklung von %2 zu unterstützen.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="33"/>
+        <location filename="../src/AboutView.cpp" line="25"/>
+        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
+        <translation>Bitte &lt;a href=&apos;%1&apos;&gt;Spenden&lt;/a&gt; um die ständige Entwicklung von %2 zu unterstützen.</translation>
+    </message>
+    <message>
+        <location filename="../src/AboutView.cpp" line="32"/>
         <source>Icon designed by %1.</source>
         <translation>Icon Entwurf durch %1.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="34"/>
+        <location filename="../src/AboutView.cpp" line="33"/>
         <source>Compact mode contributed by %1.</source>
         <translation>Kompakt Modus beigetragen von %1.</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="35"/>
+        <location filename="../src/AboutView.cpp" line="34"/>
         <source>HTTP proxy support contributed by %1.</source>
         <translation>HTTP Proxy unterstützung beigetragen von %1.</translation>
     </message>
@@ -54,17 +57,17 @@
         <translation type="obsolete">Windows Version erstellt durch %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="38"/>
+        <location filename="../src/AboutView.cpp" line="37"/>
         <source>Translated by %1</source>
         <translation>Übersetzung durch %1</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="57"/>
+        <location filename="../src/AboutView.cpp" line="63"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Veröffentlicht unter der &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/AboutView.cpp" line="68"/>
+        <location filename="../src/AboutView.cpp" line="74"/>
         <source>&amp;Close</source>
         <translation>S&amp;chließen</translation>
     </message>
@@ -121,55 +124,53 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <location filename="../src/MainWindow.cpp" line="72"/>
         <source>&amp;Back</source>
-        <translation>&amp;Zurück</translation>
+        <translation type="obsolete">&amp;Zurück</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="75"/>
         <source>Go to the previous view</source>
-        <translation>Gehe zur vorherigen Ansicht</translation>
+        <translation type="obsolete">Gehe zur vorherigen Ansicht</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="79"/>
+        <location filename="../src/MainWindow.cpp" line="81"/>
         <source>&amp;Stop</source>
         <translation>&amp;Halt</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="80"/>
+        <location filename="../src/MainWindow.cpp" line="82"/>
         <source>Stop playback and go back to the search view</source>
         <translation>Wiedergabe anhalten und zurück zur Suchansicht</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="85"/>
+        <location filename="../src/MainWindow.cpp" line="87"/>
         <source>S&amp;kip</source>
         <translation>Ü&amp;berspringen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="86"/>
+        <location filename="../src/MainWindow.cpp" line="88"/>
         <source>Skip to the next video</source>
         <translation>Überspringe zum nächsten Video</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="92"/>
-        <location filename="../src/MainWindow.cpp" line="524"/>
+        <location filename="../src/MainWindow.cpp" line="94"/>
+        <location filename="../src/MainWindow.cpp" line="535"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pause</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="93"/>
-        <location filename="../src/MainWindow.cpp" line="525"/>
+        <location filename="../src/MainWindow.cpp" line="95"/>
+        <location filename="../src/MainWindow.cpp" line="536"/>
         <source>Pause playback</source>
         <translation>Wiedergabe pausieren</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="99"/>
-        <location filename="../src/MainWindow.cpp" line="568"/>
+        <location filename="../src/MainWindow.cpp" line="101"/>
+        <location filename="../src/MainWindow.cpp" line="614"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;Vollbildmodus</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="100"/>
+        <location filename="../src/MainWindow.cpp" line="102"/>
         <source>Go full screen</source>
         <translation>Vollbildmodus aktivieren</translation>
     </message>
@@ -182,26 +183,24 @@
         <translation type="obsolete">Kompakt Ansicht aktivieren</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="125"/>
         <source>&amp;YouTube</source>
-        <translation>&amp;YouTube</translation>
+        <translation type="obsolete">&amp;YouTube</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="126"/>
         <source>Open the YouTube video page</source>
-        <translation>Öffne die YouTube Video Seite</translation>
+        <translation type="obsolete">Öffne die YouTube Video Seite</translation>
     </message>
     <message>
         <source>Ctrl+Y</source>
         <translation type="obsolete">Ctrl+Y</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="106"/>
+        <location filename="../src/MainWindow.cpp" line="108"/>
         <source>&amp;Compact mode</source>
         <translation>&amp;Kompakt-Ansicht</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="107"/>
+        <location filename="../src/MainWindow.cpp" line="109"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>Verstecke Abspielliste und Werkzeugleiste</translation>
     </message>
@@ -217,130 +216,175 @@
         <source>Ctrl+S</source>
         <translation type="obsolete">Strg+S</translation>
     </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="117"/>
+        <source>Open the &amp;YouTube page</source>
+        <translation>Öffne die &amp;YouTube Seite</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="118"/>
+        <source>Go to the YouTube video page and pause playback</source>
+        <translation>Gehe zur YouTube Video Seite und pausiere die Wiedergabe</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="124"/>
+        <source>Copy the YouTube &amp;link</source>
+        <translation>YouTube &amp;Link kopieren</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="125"/>
+        <source>Copy the current video YouTube link to the clipboard</source>
+        <translation>YouTube Link in die Zwischenablage kopieren</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="131"/>
+        <source>Copy the video stream &amp;URL</source>
+        <translation>Video &amp;URL kopieren</translation>
+    </message>
     <message>
         <location filename="../src/MainWindow.cpp" line="132"/>
+        <source>Copy the current video stream URL to the clipboard</source>
+        <translation>Video URL in die Zwischenablage kopieren</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="138"/>
         <source>&amp;Remove</source>
         <translation>Entfe&amp;rnen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="133"/>
+        <location filename="../src/MainWindow.cpp" line="139"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Entferne das ausgewählte Video aus der Abspielliste</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="139"/>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Move &amp;Up</source>
         <translation>Bewege &amp;hinauf</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="140"/>
+        <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Bewerge das ausgewählte Video in der Abspielliste hinauf</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="146"/>
+        <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Move &amp;Down</source>
         <translation>Bewege hin&amp;ab</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="147"/>
+        <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Bewege das ausgewählte Video in der Abspielliste hinunter</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="153"/>
+        <location filename="../src/MainWindow.cpp" line="159"/>
         <source>&amp;Clear recent keywords</source>
         <translation>Kürzlich genutzte S&amp;chlüsselwörter entfernen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="160"/>
+        <location filename="../src/MainWindow.cpp" line="164"/>
+        <source>Clear the search history. Cannot be undone.</source>
+        <translation>Such Historie leeren. Kann nicht rückgängig gemacht werden.</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="169"/>
         <source>&amp;Quit</source>
         <translation>&amp;Verlassen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="162"/>
+        <location filename="../src/MainWindow.cpp" line="171"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="163"/>
+        <location filename="../src/MainWindow.cpp" line="172"/>
         <source>Bye</source>
         <translation>Tschüss</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="167"/>
+        <location filename="../src/MainWindow.cpp" line="176"/>
         <source>&amp;Website</source>
         <translation>&amp;Webseite</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="169"/>
+        <location filename="../src/MainWindow.cpp" line="178"/>
         <source>%1 on the Web</source>
         <translation>%1 im Internet</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="173"/>
-        <source>&amp;Donate via PayPal</source>
-        <translation>Spen&amp;den via PayPal</translation>
+        <location filename="../src/MainWindow.cpp" line="182"/>
+        <source>Make a &amp;donation</source>
+        <translation>Eine Spen&amp;den machen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="174"/>
+        <location filename="../src/MainWindow.cpp" line="772"/>
+        <source>Maximum video definition set to %1</source>
+        <translation>Maximale video Definition wurde auf %1 gesetzt</translation>
+    </message>
+    <message>
+        <source>&amp;Donate via PayPal</source>
+        <translation type="obsolete">Spen&amp;den via PayPal</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="183"/>
         <source>Please support the continued development of %1</source>
         <translation>Bitte unterstüte die fortwährende Entwicklung von %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="178"/>
+        <location filename="../src/MainWindow.cpp" line="187"/>
         <source>&amp;About</source>
         <translation>&amp;Über</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="180"/>
+        <location filename="../src/MainWindow.cpp" line="189"/>
         <source>Info about %1</source>
         <translation>Informationen über %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="188"/>
+        <location filename="../src/MainWindow.cpp" line="197"/>
         <source>Search</source>
         <translation>Suche</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="206"/>
+        <location filename="../src/MainWindow.cpp" line="216"/>
         <source>Mute volume</source>
         <translation>Audio ausschalten</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="207"/>
+        <location filename="../src/MainWindow.cpp" line="218"/>
         <source>Ctrl+M</source>
         <translation>Strg+M</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="324"/>
+        <location filename="../src/MainWindow.cpp" line="352"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
         <translation>%1 drücken um die Lautstärke zu erhöhen, %2 um sie zu verringern</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="674"/>
+        <location filename="../src/MainWindow.cpp" line="710"/>
         <source>Remaining time: %1</source>
         <translation>Verbleibende Zeit: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="782"/>
         <source>High Definition video is enabled</source>
-        <translation>High Definition Video ist eingeschaltet</translation>
+        <translation type="obsolete">High Definition Video ist eingeschaltet</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="784"/>
         <source>High Definition video is not enabled</source>
-        <translation>High Definition Video ist nicht eingeschaltet</translation>
+        <translation type="obsolete">High Definition Video ist nicht eingeschaltet</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="795"/>
         <source>The current video is in High Definition</source>
-        <translation>Das derzeitige Video ist in High Definition</translation>
+        <translation type="obsolete">Das derzeitige Video ist in High Definition</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="798"/>
         <source>The current video is not in High Definition</source>
-        <translation>Das derzeitige Video ist nicht in High Definition</translation>
+        <translation type="obsolete">Das derzeitige Video ist nicht in High Definition</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="812"/>
+        <source>Your privacy is now safe</source>
+        <translation>Deine Privatsphäre ist nun geschützt</translation>
     </message>
     <message>
         <source>No Video playing</source>
@@ -375,17 +419,17 @@
         <translation type="obsolete">Herunterladen fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="720"/>
+        <location filename="../src/MainWindow.cpp" line="756"/>
         <source>Volume at %1%</source>
         <translation>Lautstärke %1%</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="725"/>
+        <location filename="../src/MainWindow.cpp" line="762"/>
         <source>Volume is muted</source>
         <translation>Audio ist ausgeschaltet</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="727"/>
+        <location filename="../src/MainWindow.cpp" line="765"/>
         <source>Volume is unmuted</source>
         <translation>Audio eingeschaltet</translation>
     </message>
@@ -394,53 +438,53 @@
         <translation type="obsolete">&amp;Suche</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="254"/>
+        <location filename="../src/MainWindow.cpp" line="268"/>
         <source>&amp;Application</source>
         <translation>&amp;Anwendung</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="263"/>
+        <location filename="../src/MainWindow.cpp" line="276"/>
         <source>&amp;Playlist</source>
         <translation>&amp;Abspielliste</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="270"/>
+        <location filename="../src/MainWindow.cpp" line="283"/>
         <source>&amp;Video</source>
         <translation>&amp;Video</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="283"/>
+        <location filename="../src/MainWindow.cpp" line="296"/>
         <source>&amp;Help</source>
         <translation>&amp;Hilfe</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="465"/>
-        <location filename="../src/MainWindow.cpp" line="471"/>
+        <location filename="../src/MainWindow.cpp" line="476"/>
+        <location filename="../src/MainWindow.cpp" line="482"/>
         <source>Opening %1</source>
         <translation>Öffne %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="515"/>
+        <location filename="../src/MainWindow.cpp" line="526"/>
         <source>Fatal error: %1</source>
         <translation>Schwerer Fehler: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="517"/>
+        <location filename="../src/MainWindow.cpp" line="528"/>
         <source>Error: %1</source>
         <translation>Fehler: %1</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="538"/>
+        <location filename="../src/MainWindow.cpp" line="549"/>
         <source>&amp;Play</source>
         <translation>&amp;Abspielen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="539"/>
+        <location filename="../src/MainWindow.cpp" line="550"/>
         <source>Resume playback</source>
         <translation>Wiedergabe fortsetzen</translation>
     </message>
     <message>
-        <location filename="../src/MainWindow.cpp" line="577"/>
+        <location filename="../src/MainWindow.cpp" line="627"/>
         <source>Exit &amp;Full Screen</source>
         <translation>Vollbildmodus &amp;verlassen</translation>
     </message>
@@ -448,20 +492,55 @@
 <context>
     <name>MediaView</name>
     <message>
-        <location filename="../src/MediaView.cpp" line="25"/>
+        <location filename="../src/MediaView.cpp" line="30"/>
         <source>Most relevant</source>
         <translation>Die bedeutsamsten</translation>
     </message>
     <message>
-        <location filename="../src/MediaView.cpp" line="32"/>
+        <location filename="../src/MediaView.cpp" line="37"/>
         <source>Most recent</source>
         <translation>Die neusten</translation>
     </message>
     <message>
-        <location filename="../src/MediaView.cpp" line="39"/>
+        <location filename="../src/MediaView.cpp" line="44"/>
         <source>Most viewed</source>
         <translation>Meist gesehen</translation>
     </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="357"/>
+        <source>You can now paste the YouTube link into another application</source>
+        <translation>Du kann den YouTube Link nun in einer anderen Anwendung einfügen</translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="365"/>
+        <source>You can now paste the video stream URL into another application</source>
+        <translation>Die kannst die Video URL nun in einer anderen Anwendung einfügen</translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="366"/>
+        <source>The link will be valid only for a limited time.</source>
+        <translation>Der Link wird nur eine beschränkte Zeit gültig sein.</translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="449"/>
+        <source>This is just the demo version of %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="450"/>
+        <source>It allows you to test the application and see if it works for you.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="454"/>
+        <source>Continue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../src/MediaView.cpp" line="455"/>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
     <message>
         <location filename="../src/MediaView.h" line="31"/>
         <source>You&apos;re watching &quot;%1&quot;</source>
@@ -471,7 +550,7 @@
 <context>
     <name>NetworkAccess</name>
     <message>
-        <location filename="../src/networkaccess.cpp" line="188"/>
+        <location filename="../src/networkaccess.cpp" line="192"/>
         <source>Network error: %1</source>
         <translation>Netzwerk Fehler: %1</translation>
     </message>
@@ -495,32 +574,32 @@
 <context>
     <name>SearchView</name>
     <message>
-        <location filename="../src/SearchView.cpp" line="52"/>
+        <location filename="../src/SearchView.cpp" line="46"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Willkommen bei &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="61"/>
+        <location filename="../src/SearchView.cpp" line="55"/>
         <source>Enter a keyword to start watching videos.</source>
         <translation>Schlüsselwort eingeben um die Wiedergabe zu starten.</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="81"/>
+        <location filename="../src/SearchView.cpp" line="75"/>
         <source>Watch</source>
         <translation>Anschauen</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="97"/>
+        <location filename="../src/SearchView.cpp" line="91"/>
         <source>Recent keywords</source>
         <translation>Aktuelle Schlüsselwörter</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.cpp" line="208"/>
+        <location filename="../src/SearchView.cpp" line="186"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
         <translation>Eine neue Version von %1 ist verfügbar. Bitte &lt;a href=&apos;%2&apos;&gt;auf Version %3 aktuallisieren&lt;/a&gt;</translation>
     </message>
     <message>
-        <location filename="../src/SearchView.h" line="28"/>
+        <location filename="../src/SearchView.h" line="29"/>
         <source>Make yourself comfortable</source>
         <translation>Mach es Dir gemütlich</translation>
     </message>
@@ -528,9 +607,8 @@
 <context>
     <name>SettingsView</name>
     <message>
-        <location filename="../src/SettingsView.h" line="17"/>
         <source>Preferences</source>
-        <translation>Einstellungen</translation>
+        <translation type="obsolete">Einstellungen</translation>
     </message>
     <message>
         <source>&amp;Close</source>
@@ -540,7 +618,7 @@
 <context>
     <name>Video</name>
     <message>
-        <location filename="../src/video.cpp" line="139"/>
+        <location filename="../src/video.cpp" line="145"/>
         <source>Network error: %1 for %2</source>
         <translation>Netzwerk Fehler: %1 für %2</translation>
     </message>
