@@ -14,11 +14,11 @@
     </message>
     <message>
         <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
-        <translation>Эта предварительная версия, не стоит ожидать совершенства.</translation>
+        <translation type="obsolete">Эта предварительная версия, не стоит ожидать совершенства.</translation>
     </message>
     <message>
         <source>Report bugs and send in your ideas to %1</source>
-        <translation type="unfinished">Отзывы и сообщения об ошибках следует отправлять на %1</translation>
+        <translation>Отзывы и сообщения об ошибках следует отправлять на %1</translation>
     </message>
     <message>
         <source>%1 is Free Software but its development takes precious time.</source>
@@ -26,7 +26,7 @@
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
-        <translation>&lt;a href=&apos;%1&apos;&gt;Поддержите через PayPal&lt;/a&gt; дальнейшую разработку %2.</translation>
+        <translation type="obsolete">&lt;a href=&apos;%1&apos;&gt;Поддержите через PayPal&lt;/a&gt; дальнейшую разработку %2.</translation>
     </message>
     <message>
         <source>Icon designed by %1.</source>
@@ -34,7 +34,7 @@
     </message>
     <message>
         <source>Translated by %1</source>
-        <translation type="unfinished">Перевод выполнили: %1</translation>
+        <translation>Перевод выполнили: %1</translation>
     </message>
     <message>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
@@ -54,16 +54,20 @@
     </message>
     <message>
         <source>Compact mode contributed by %1.</source>
-        <translation>Компактный режим предоставлен %1.</translation>
+        <translation>Облегчённый режим предоставлен %1.</translation>
     </message>
     <message>
         <source>HTTP proxy support contributed by %1.</source>
-        <translation type="unfinished">Поддержка HTTP-прокси предоставлена %1.</translation>
+        <translation>Поддержка HTTP-прокси предоставлена %1.</translation>
     </message>
     <message>
         <source>Windows version built by %1</source>
         <translation type="obsolete">Сборку под Windows выполнил %1</translation>
     </message>
+    <message>
+        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
+        <translation>&lt;a href=&apos;%1&apos;&gt;Поддержите&lt;/a&gt; дальнейшую разработку %2.</translation>
+    </message>
 </context>
 <context>
     <name>ClearButton</name>
@@ -84,11 +88,11 @@
     </message>
     <message>
         <source>No videos</source>
-        <translation>Видео не найдено</translation>
+        <translation>Клипы не найдены</translation>
     </message>
     <message>
         <source>No more videos</source>
-        <translation>Больше нет видео</translation>
+        <translation>Больше нет клипов</translation>
     </message>
 </context>
 <context>
@@ -102,7 +106,7 @@
     <name>MainWindow</name>
     <message>
         <source>&amp;Back</source>
-        <translation>&amp;Назад</translation>
+        <translation type="obsolete">&amp;Назад</translation>
     </message>
     <message>
         <source>Alt+Left</source>
@@ -110,7 +114,7 @@
     </message>
     <message>
         <source>Go to the previous view</source>
-        <translation>Перейти к предыдущему</translation>
+        <translation type="obsolete">Перейти к предыдущему</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
@@ -130,7 +134,7 @@
     </message>
     <message>
         <source>Skip to the next video</source>
-        <translation>Перейти к следующему видео</translation>
+        <translation>Перейти к следующему клипу</translation>
     </message>
     <message>
         <source>Ctrl+Right</source>
@@ -162,11 +166,11 @@
     </message>
     <message>
         <source>&amp;YouTube</source>
-        <translation>&amp;YouTube</translation>
+        <translation type="obsolete">&amp;YouTube</translation>
     </message>
     <message>
         <source>Open the YouTube video page</source>
-        <translation>Открыть страницу видео в YouTube</translation>
+        <translation type="obsolete">Открыть страницу видео в YouTube</translation>
     </message>
     <message>
         <source>Ctrl+Y</source>
@@ -178,7 +182,7 @@
     </message>
     <message>
         <source>Remove the selected videos from the playlist</source>
-        <translation>Удалить выбранные видеоклипы из списка воспроизведения</translation>
+        <translation>Удалить выбранные клипы из списка воспроизведения</translation>
     </message>
     <message>
         <source>Move &amp;Up</source>
@@ -186,7 +190,7 @@
     </message>
     <message>
         <source>Move up the selected videos in the playlist</source>
-        <translation type="unfinished">Переместить выбранные видеоклипы вверх в списке воспроизведения</translation>
+        <translation>Переместить выбранные видеоклипы вверх в списке воспроизведения</translation>
     </message>
     <message>
         <source>Ctrl+Up</source>
@@ -198,7 +202,7 @@
     </message>
     <message>
         <source>Move down the selected videos in the playlist</source>
-        <translation type="unfinished">Переместить выбранные видеоклипы вниз в списке воспроизведения</translation>
+        <translation>Переместить выбранные видеоклипы вниз в списке воспроизведения</translation>
     </message>
     <message>
         <source>Ctrl+Down</source>
@@ -230,7 +234,7 @@
     </message>
     <message>
         <source>&amp;Donate via PayPal</source>
-        <translation>&amp;Поддержать через PayPal</translation>
+        <translation type="obsolete">&amp;Поддержать через PayPal</translation>
     </message>
     <message>
         <source>Please support the continued development of %1</source>
@@ -250,7 +254,7 @@
     </message>
     <message>
         <source>&amp;Application</source>
-        <translation type="unfinished">Пр&amp;иложение</translation>
+        <translation>Пр&amp;иложение</translation>
     </message>
     <message>
         <source>&amp;Playlist</source>
@@ -258,7 +262,7 @@
     </message>
     <message>
         <source>&amp;Video</source>
-        <translation>&amp;Видео</translation>
+        <translation>&amp;Клипы</translation>
     </message>
     <message>
         <source>&amp;Help</source>
@@ -282,7 +286,7 @@
     </message>
     <message>
         <source>&amp;Compact mode</source>
-        <translation>&amp;Компактный режим</translation>
+        <translation>&amp;Облегчённый режим</translation>
     </message>
     <message>
         <source>Hide the playlist and the toolbar</source>
@@ -330,23 +334,63 @@
     </message>
     <message>
         <source>High Definition video is enabled</source>
-        <translation type="unfinished">Показ видео в высоком разрешении включен</translation>
+        <translation type="obsolete">Показ видео в высоком разрешении включен</translation>
     </message>
     <message>
         <source>High Definition video is not enabled</source>
-        <translation type="unfinished">Показ видео в высоком разрешении выключен</translation>
+        <translation type="obsolete">Показ видео в высоком разрешении выключен</translation>
     </message>
     <message>
         <source>The current video is in High Definition</source>
-        <translation type="unfinished">Видео воспроизводится в высоком разрешении</translation>
+        <translation type="obsolete">Видео воспроизводится в высоком разрешении</translation>
     </message>
     <message>
         <source>The current video is not in High Definition</source>
-        <translation type="unfinished">Видео воспроизводится не в высоком разрешении</translation>
+        <translation type="obsolete">Видео воспроизводится не в высоком разрешении</translation>
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation type="unfinished">&amp;Очистить последние запросы</translation>
+        <translation>&amp;Очистить последние запросы</translation>
+    </message>
+    <message>
+        <source>Clear the search history. Cannot be undone.</source>
+        <translation>Очистить журнал запросов. Изменения необратимы.</translation>
+    </message>
+    <message>
+        <source>Your privacy is now safe</source>
+        <translation>Конфиденциальность обеспечена</translation>
+    </message>
+    <message>
+        <source>Open the &amp;YouTube page</source>
+        <translation>Открыть страницу &amp;YouTube</translation>
+    </message>
+    <message>
+        <source>Go to the YouTube video page and pause playback</source>
+        <translation>Приостановить воспроизведение и перейти на страницу видео в YouTube</translation>
+    </message>
+    <message>
+        <source>Copy the YouTube &amp;link</source>
+        <translation>Копировать &amp;ссылку YouTube</translation>
+    </message>
+    <message>
+        <source>Copy the current video YouTube link to the clipboard</source>
+        <translation>Скопировать ссылку текущего клипа YouTube в буфер обмена</translation>
+    </message>
+    <message>
+        <source>Copy the video stream &amp;URL</source>
+        <translation>Копировать &amp;адрес видео потока</translation>
+    </message>
+    <message>
+        <source>Copy the current video stream URL to the clipboard</source>
+        <translation>Скопировать адрес текущего видео потока в буфер обмена</translation>
+    </message>
+    <message>
+        <source>Make a &amp;donation</source>
+        <translation>Сделать &amp;пожертвование</translation>
+    </message>
+    <message>
+        <source>Maximum video definition set to %1</source>
+        <translation>Максимальное разрешение видео: %1</translation>
     </message>
 </context>
 <context>
@@ -367,6 +411,34 @@
         <source>You&apos;re watching &quot;%1&quot;</source>
         <translation>Сейчас просматривается &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>You can now paste the YouTube link into another application</source>
+        <translation>Теперь можно вставить адрес YouTube в другое приложение</translation>
+    </message>
+    <message>
+        <source>You can now paste the video stream URL into another application</source>
+        <translation>Теперь можно вставить адрес видео потока в другое приложение</translation>
+    </message>
+    <message>
+        <source>The link will be valid only for a limited time.</source>
+        <translation>Адрес будет существовать ограниченное время.</translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It allows you to test the application and see if it works for you.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NetworkAccess</name>
@@ -420,7 +492,7 @@
     <name>SettingsView</name>
     <message>
         <source>Preferences</source>
-        <translation>Настройки</translation>
+        <translation type="obsolete">Настройки</translation>
     </message>
     <message>
         <source>&amp;Video options</source>
