@@ -14,7 +14,7 @@
     </message>
     <message>
         <source>This is a &quot;Technology Preview&quot; release, do not expect it to be perfect.</source>
-        <translation>Це технологічний попередній випуск програми, не очікуйте від нього досконалості.</translation>
+        <translation type="obsolete">Це технологічний попередній випуск програми, не очікуйте від нього досконалості.</translation>
     </message>
     <message>
         <source>Report bugs and send in your ideas to %1</source>
@@ -26,7 +26,7 @@
     </message>
     <message>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate via PayPal&lt;/a&gt; to support the continued development of %2.</source>
-        <translation>Будь ласка  &lt;a href=&apos;%1&apos;&gt;скористайтесь PayPal&lt;/a&gt; щоб підтримати подальший розвиток %2.</translation>
+        <translation type="obsolete">Будь ласка  &lt;a href=&apos;%1&apos;&gt;скористайтесь PayPal&lt;/a&gt; щоб підтримати подальший розвиток %2.</translation>
     </message>
     <message>
         <source>Icon designed by %1.</source>
@@ -64,6 +64,10 @@
         <source>Windows version built by %1</source>
         <translation type="obsolete">Версія для Windows %1</translation>
     </message>
+    <message>
+        <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
+        <translation>Будь ласка &lt;a href=&apos;%1&apos;&gt;внесіть пожертву&lt;/a&gt; щоб підтримати подальший розвиток %2.</translation>
+    </message>
 </context>
 <context>
     <name>ClearButton</name>
@@ -102,7 +106,7 @@
     <name>MainWindow</name>
     <message>
         <source>&amp;Back</source>
-        <translation>&amp;Назад</translation>
+        <translation type="obsolete">&amp;Назад</translation>
     </message>
     <message>
         <source>Alt+Left</source>
@@ -110,7 +114,7 @@
     </message>
     <message>
         <source>Go to the previous view</source>
-        <translation>Повернутися до попереднього режиму</translation>
+        <translation type="obsolete">Повернутися до попереднього режиму</translation>
     </message>
     <message>
         <source>&amp;Stop</source>
@@ -162,11 +166,11 @@
     </message>
     <message>
         <source>&amp;YouTube</source>
-        <translation>&amp;YouTube</translation>
+        <translation type="obsolete">&amp;YouTube</translation>
     </message>
     <message>
         <source>Open the YouTube video page</source>
-        <translation>Відкрити сторінку YouTube</translation>
+        <translation type="obsolete">Відкрити сторінку YouTube</translation>
     </message>
     <message>
         <source>Ctrl+Y</source>
@@ -230,7 +234,7 @@
     </message>
     <message>
         <source>&amp;Donate via PayPal</source>
-        <translation>Підтрима&amp;йте проект через PayPal</translation>
+        <translation type="obsolete">Підтрима&amp;йте проект через PayPal</translation>
     </message>
     <message>
         <source>Please support the continued development of %1</source>
@@ -250,7 +254,7 @@
     </message>
     <message>
         <source>&amp;Application</source>
-        <translation type="unfinished">&amp;Програма</translation>
+        <translation>&amp;Програма</translation>
     </message>
     <message>
         <source>&amp;Playlist</source>
@@ -330,23 +334,63 @@
     </message>
     <message>
         <source>High Definition video is enabled</source>
-        <translation>Відео високої чіткості активоване</translation>
+        <translation type="obsolete">Відео високої чіткості активоване</translation>
     </message>
     <message>
         <source>High Definition video is not enabled</source>
-        <translation>Відео високої чіткості не активоване</translation>
+        <translation type="obsolete">Відео високої чіткості не активоване</translation>
     </message>
     <message>
         <source>The current video is in High Definition</source>
-        <translation>Відео в режимі високої чіткості</translation>
+        <translation type="obsolete">Відео в режимі високої чіткості</translation>
     </message>
     <message>
         <source>The current video is not in High Definition</source>
-        <translation>ВІдео не в режимі високої чіткості</translation>
+        <translation type="obsolete">ВІдео не в режимі високої чіткості</translation>
     </message>
     <message>
         <source>&amp;Clear recent keywords</source>
-        <translation type="unfinished">Очистити недавн&amp;і терміни пошуку</translation>
+        <translation>Очистити недавн&amp;і терміни пошуку</translation>
+    </message>
+    <message>
+        <source>Clear the search history. Cannot be undone.</source>
+        <translation>Очистити історію пошуку (зміни незвороні).</translation>
+    </message>
+    <message>
+        <source>Your privacy is now safe</source>
+        <translation>Ваша приватність застережена</translation>
+    </message>
+    <message>
+        <source>Open the &amp;YouTube page</source>
+        <translation>&amp;Відкрити сторінку YouTube</translation>
+    </message>
+    <message>
+        <source>Go to the YouTube video page and pause playback</source>
+        <translation>Відкрити сторінку YouTube і призупини відтворення відео</translation>
+    </message>
+    <message>
+        <source>Copy the YouTube &amp;link</source>
+        <translation>Скопіювати YouTube &amp;посилання в буфер</translation>
+    </message>
+    <message>
+        <source>Copy the current video YouTube link to the clipboard</source>
+        <translation>Скопіювати YouTube посилання поточного відео в буфер</translation>
+    </message>
+    <message>
+        <source>Copy the video stream &amp;URL</source>
+        <translation>Скопіювати &amp;посилання в буфер</translation>
+    </message>
+    <message>
+        <source>Copy the current video stream URL to the clipboard</source>
+        <translation>Скопіювати посилання поточного відео в буфер</translation>
+    </message>
+    <message>
+        <source>Make a &amp;donation</source>
+        <translation>Підтрима&amp;йте проект</translation>
+    </message>
+    <message>
+        <source>Maximum video definition set to %1</source>
+        <translation>Режим чіткості відео %1</translation>
     </message>
 </context>
 <context>
@@ -367,6 +411,34 @@
         <source>You&apos;re watching &quot;%1&quot;</source>
         <translation>Ви дивитесь &quot;%1&quot;</translation>
     </message>
+    <message>
+        <source>You can now paste the YouTube link into another application</source>
+        <translation>Ви можете використовувати YouTube посилання на відео в завнішній програмі </translation>
+    </message>
+    <message>
+        <source>You can now paste the video stream URL into another application</source>
+        <translation>Ви можете використовувати посилання на відео в завнішній програмі </translation>
+    </message>
+    <message>
+        <source>The link will be valid only for a limited time.</source>
+        <translation>Посилання буде дійсне тільки протягом обмеженого часу.</translation>
+    </message>
+    <message>
+        <source>This is just the demo version of %1.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>It allows you to test the application and see if it works for you.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Continue</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Get the full version</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>NetworkAccess</name>
@@ -420,7 +492,7 @@
     <name>SettingsView</name>
     <message>
         <source>Preferences</source>
-        <translation>Налаштування</translation>
+        <translation type="obsolete">Налаштування</translation>
     </message>
     <message>
         <source>&amp;Video options</source>
