@@ -1,5 +1,5 @@
 #include "AboutView.h"
-#include "Constants.h"
+#include "constants.h"
 
 AboutView::AboutView(QWidget *parent) : QWidget(parent) {
 
@@ -20,14 +20,13 @@ AboutView::AboutView(QWidget *parent) : QWidget(parent) {
                    "<p>" + tr("There's life outside the browser!") + "</p>"
                    "<p>" + tr("Version %1").arg(Constants::VERSION) + "</p>"
                    + QString("<p><a href=\"%1/\">%1</a></p>").arg(Constants::WEBSITE) +
-
-                   "<p>" + tr("This is a \"Technology Preview\" release, do not expect it to be perfect.") + "<br/>"
-                   + tr("Report bugs and send in your ideas to %1")
-                   .arg(QString("<a href=\"mailto:%1\">%1</a>").arg(Constants::EMAIL)) + "</p>"
-
+#if !defined(APP_MAC) && !defined(Q_WS_WIN)
                    "<p>" +  tr("%1 is Free Software but its development takes precious time.").arg(Constants::APP_NAME) + "<br/>"
-                   + tr("Please <a href='%1'>donate via PayPal</a> to support the continued development of %2.")
+                   + tr("Please <a href='%1'>donate</a> to support the continued development of %2.")
                    .arg(QString(Constants::WEBSITE).append("#donate"), Constants::APP_NAME) + "</p>"
+#endif
+                   "<p>" + tr("Report bugs and send in your ideas to %1")
+                   .arg(QString("<a href=\"mailto:%1\">%1</a>").arg(Constants::EMAIL)) + "</p>"
 
                    "<p>"
                    + tr("Icon designed by %1.").arg("Sebastian Kraft")
@@ -37,26 +36,34 @@ AboutView::AboutView(QWidget *parent) : QWidget(parent) {
 
                    "<p>" + tr("Translated by %1").arg("Nikita Lyalin (ru_RU), "
                                                       "Márcio Moraes (pt_BR), "
-                                                      "Sergio Tocalini Joerg (es_AR), "
+                                                      // "Sergio Tocalini Joerg (es_AR), "
                                                       "Stefan Brück (de_DE), "
                                                       "Grzegorz Gibas (pl_PL), "
                                                       "Kiwamu Okabe (ja_JP), "
                                                       "Dan Vrátil (cs_CZ), "
-                                                      "Rafa (es_ES), "
+                                                      // "Rafa (es_ES), "
                                                       "Yaron Shahrabani (he_IL), "
                                                       "Oleksandr Korneta (uk), "
                                                       "Inga Muste (lat), "
-                                                      "Srecko Belaic (hr_HR), "
+                                                      "Srecko Belaic & Zvonimir Đeri (hr_HR), "
                                                       "Miguel Anxo Bouzada (es, gl), "
-                                                      "Guillaume Betous (fr_FR), "
+                                                      "Guillaume Betous & Mathieu Dimanche (fr_FR), "
                                                       "Krisztián Horváth (hu_HU), "
                                                       "Ali E. İmrek (tr_TR), "
-                                                      "Jan W. Skjoldal (nb_NO)"
+                                                      "Jan W. Skjoldal & Halvor Lyche Strandvoll (nb_NO), "
+                                                      "Ovidiu Niţan (ro_RO), "
+                                                      "Giorgos Skettos (el_GR), "
+                                                      "Brian Keetman (nl_NL), "
+                                                      "Sderawi (ar), "
+                                                      "Daniel Rodrigues (pt_PT), "
+                                                      "Jesse Jaara (fi_FI), "
+                                                      "Tsvyatko Makazchiev (bg_BG), "
+                                                      "Changtai Liang (zh_CN)"
                                                       ) + "</p>"
-
+#if !defined(APP_MAC) && !defined(Q_WS_WIN)
                    "<p>" + tr("Released under the <a href='%1'>GNU General Public License</a>")
                    .arg("http://www.gnu.org/licenses/gpl.html") + "</p>"
-
+#endif
                    "<p>&copy; 2009-2010 " + Constants::ORG_NAME + "</p>";
     QLabel *infoLabel = new QLabel(info, this);
     infoLabel->setOpenExternalLinks(true);
