@@ -4,6 +4,7 @@
 #include "videowidget.h"
 #include "minisplitter.h"
 #include "flickcharm.h"
+#include "constants.h"
 
 namespace The {
     QMap<QString, QAction*>* globalActions();
@@ -13,6 +14,10 @@ namespace The {
 
 MediaView::MediaView(QWidget *parent) : QWidget(parent) {
 
+#ifdef APP_DEMO
+    tracksPlayed = 0;
+#endif
+
     reallyStopped = false;
 
     QBoxLayout *layout = new QHBoxLayout();
@@ -81,8 +86,7 @@ MediaView::MediaView(QWidget *parent) : QWidget(parent) {
     videoAreaWidget = new VideoAreaWidget(this);
     videoAreaWidget->setMinimumSize(320,240);
 
-
-#ifdef Q_WS_MAC
+#ifdef APP_MAC
     // mouse autohide does not work on the Mac (no mouseMoveEvent)
     videoWidget = new Phonon::VideoWidget(this);
 #else
@@ -114,6 +118,7 @@ MediaView::MediaView(QWidget *parent) : QWidget(parent) {
     workaroundTimer->setInterval(3000);
     connect(workaroundTimer, SIGNAL(timeout()), SLOT(timerPlay()));
 
+    // TODO Enable this on touch devices
     // FlickCharm *flickCharm = new FlickCharm(this);
     // flickCharm->activateOn(listView);
 
@@ -133,7 +138,6 @@ void MediaView::initialize() {
 void MediaView::setMediaObject(Phonon::MediaObject *mediaObject) {
     this->mediaObject = mediaObject;
     Phonon::createPath(this->mediaObject, videoWidget);
-    // connect(mediaObject, SIGNAL(aboutToFinish()), this, SLOT(aboutToFinish()));
     connect(mediaObject, SIGNAL(finished()), this, SLOT(skip()));
     connect(mediaObject, SIGNAL(stateChanged(Phonon::State, Phonon::State)),
             this, SLOT(stateChanged(Phonon::State, Phonon::State)));
@@ -145,6 +149,10 @@ void MediaView::setMediaObject(Phonon::MediaObject *mediaObject) {
 void MediaView::search(SearchParams *searchParams) {
     reallyStopped = false;
 
+#ifdef APP_DEMO
+    tracksPlayed = 0;
+#endif
+
     videoAreaWidget->clear();
     workaroundTimer->stop();
     errorTimer->stop();
@@ -179,23 +187,23 @@ void MediaView::stateChanged(Phonon::State newState, Phonon::State /*oldState*/)
 
     switch (newState) {
 
-         case Phonon::ErrorState:
+    case Phonon::ErrorState:
         qDebug() << "Phonon error:" << mediaObject->errorString() << mediaObject->errorType();
         handleError(mediaObject->errorString());
         break;
 
-         case Phonon::PlayingState:
+    case Phonon::PlayingState:
         //qDebug("playing");
         videoAreaWidget->showVideo();
         break;
 
-         case Phonon::StoppedState:
+    case Phonon::StoppedState:
         //qDebug("stopped");
         // play() has already been called when setting the source
         // but Phonon on Linux needs a little more help to start playback
         if (!reallyStopped) mediaObject->play();
 
-#ifdef Q_WS_MAC
+#ifdef APP_MAC
         // Workaround for Mac playback start problem
         if (!timerPlayFlag) {
             workaroundTimer->start();
@@ -241,12 +249,6 @@ void MediaView::stop() {
     workaroundTimer->stop();
     errorTimer->stop();
     listView->selectionModel()->clearSelection();
-
-    // turn off HD indicator
-    bool ret = QMetaObject::invokeMethod(parent()->parent(), "hdIndicator", Qt::DirectConnection, Q_ARG(bool, false));
-    if (!ret) qDebug() << "hdIndicator invokeMethod failed";
-    QAction *hdAct = The::globalActions()->value("hd");
-    hdAct->setToolTip("");
 }
 
 void MediaView::activeRowChanged(int row) {
@@ -273,7 +275,7 @@ void MediaView::activeRowChanged(int row) {
     timerPlayFlag = false;
 
     // video title in the statusbar
-    QMainWindow* mainWindow = dynamic_cast<QMainWindow*>(qApp->topLevelWidgets().first());
+    QMainWindow* mainWindow = dynamic_cast<QMainWindow*>(window());
     if (mainWindow) mainWindow->statusBar()->showMessage(video->title());
 
     // see you in gotStreamUrl...
@@ -284,6 +286,7 @@ void MediaView::gotStreamUrl(QUrl streamUrl) {
     if (reallyStopped) return;
 
     // go!
+    qDebug() << "Playing" << streamUrl.toString();
     mediaObject->setCurrentSource(streamUrl);
     mediaObject->play();
 
@@ -297,16 +300,11 @@ void MediaView::gotStreamUrl(QUrl streamUrl) {
         listView->scrollTo(index, QAbstractItemView::EnsureVisible);
     }
 
-    // HD indicator
+#ifdef APP_DEMO
+    if (tracksPlayed > 1) demoExpired();
+    else tracksPlayed++;
+#endif
 
-    // get the Video that sent the signal
-    Video *video = static_cast<Video *>(sender());
-    if (!video) {
-        qDebug() << "Cannot get sender";
-        return;
-    }
-    bool ret = QMetaObject::invokeMethod(parent()->parent(), "hdIndicator", Qt::DirectConnection, Q_ARG(bool, video->isHd()));
-    if (!ret) qDebug() << "hdIndicator invokeMethod failed";
 }
 
 void MediaView::itemActivated(const QModelIndex &index) {
@@ -316,21 +314,9 @@ void MediaView::itemActivated(const QModelIndex &index) {
     else listModel->searchMore();
 }
 
-void MediaView::aboutToFinish() {
-    /*
-    int nextRow = listModel->nextRow();
-    if (nextRow == -1) return;
-    Video* video = listModel->videoAt(nextRow);
-    QUrl streamUrl = video->streamUrl();
-    qDebug() << "Enqueing" << streamUrl;
-    mediaObject->enqueue(streamUrl);
-    */
-}
-
 void MediaView::currentSourceChanged(const Phonon::MediaSource source) {
-    qDebug() << "Playing" << source.url().toString();
-}
 
+}
 
 void MediaView::skipVideo() {
     // skippedVideo is useful for DELAYED skip operations
@@ -361,6 +347,27 @@ void MediaView::openWebPage() {
     QDesktopServices::openUrl(video->webpage());
 }
 
+void MediaView::copyWebPage() {
+    Video* video = listModel->activeVideo();
+    if (!video) return;
+    QString address = video->webpage().toString();
+    address.remove("&feature=youtube_gdata");
+    QApplication::clipboard()->setText(address);
+    QMainWindow* mainWindow = dynamic_cast<QMainWindow*>(window());
+    QString message = tr("You can now paste the YouTube link into another application");
+    if (mainWindow) mainWindow->statusBar()->showMessage(message);
+}
+
+void MediaView::copyVideoLink() {
+    Video* video = listModel->activeVideo();
+    if (!video) return;
+    QApplication::clipboard()->setText(video->getStreamUrl().toString());
+    QString message = tr("You can now paste the video stream URL into another application")
+                      + ". " + tr("The link will be valid only for a limited time.");
+    QMainWindow* mainWindow = dynamic_cast<QMainWindow*>(window());
+    if (mainWindow) mainWindow->statusBar()->showMessage(message);
+}
+
 void MediaView::removeSelected() {
     if (!listView->selectionModel()->hasSelection()) return;
     QModelIndexList indexes = listView->selectionModel()->selectedIndexes();
@@ -384,14 +391,26 @@ void MediaView::selectionChanged(const QItemSelection & /*selected*/, const QIte
 
 void MediaView::moveUpSelected() {
     if (!listView->selectionModel()->hasSelection()) return;
+
     QModelIndexList indexes = listView->selectionModel()->selectedIndexes();
+    qStableSort(indexes.begin(), indexes.end());
     listModel->move(indexes, true);
+
+    // set current index after row moves to something more intuitive
+    int row = indexes.first().row();
+    listView->selectionModel()->setCurrentIndex(listModel->index(row>1?row:1), QItemSelectionModel::NoUpdate);
 }
 
 void MediaView::moveDownSelected() {
     if (!listView->selectionModel()->hasSelection()) return;
+
     QModelIndexList indexes = listView->selectionModel()->selectedIndexes();
+    qStableSort(indexes.begin(), indexes.end(), qGreater<QModelIndex>());
     listModel->move(indexes, false);
+
+    // set current index after row moves to something more intuitive (respect 1 static item on bottom)
+    int row = indexes.first().row()+1, max = listModel->rowCount() - 2;
+    listView->selectionModel()->setCurrentIndex(listModel->index(row>max?max:row), QItemSelectionModel::NoUpdate);
 }
 
 void MediaView::showVideoContextMenu(QPoint point) {
@@ -432,3 +451,29 @@ void MediaView::saveSplitterState() {
     QSettings settings;
     settings.setValue("splitter", splitter->saveState());
 }
+
+#ifdef APP_DEMO
+void MediaView::demoExpired() {
+    mediaObject->pause();
+
+    QMessageBox msgBox;
+    msgBox.setIconPixmap(QPixmap(":/images/app.png").scaled(64, 64, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+    msgBox.setText(tr("This is just the demo version of %1.").arg(Constants::APP_NAME) + " " +
+                   tr("It allows you to test the application and see if it works for you.")
+                   );
+    msgBox.setModal(true);
+
+    QPushButton *quitButton = msgBox.addButton(tr("Continue"), QMessageBox::RejectRole);
+    QPushButton *buyButton = msgBox.addButton(tr("Get the full version"), QMessageBox::ActionRole);
+
+    msgBox.exec();
+
+    if (msgBox.clickedButton() == buyButton) {
+        QDesktopServices::openUrl(QString(Constants::WEBSITE) + "#download");
+    } else {
+        mediaObject->play();
+    }
+
+    tracksPlayed = 1;
+}
+#endif
