@@ -42,6 +42,8 @@ public slots:
     void skip();
     void skipVideo();
     void openWebPage();
+    void copyWebPage();
+    void copyVideoLink();
     void removeSelected();
     void moveUpSelected();
     void moveDownSelected();
@@ -58,7 +60,6 @@ private slots:
     void handleError(QString message);
     // phonon
     void stateChanged(Phonon::State newState, Phonon::State oldState);
-    void aboutToFinish();
     void currentSourceChanged(const Phonon::MediaSource source);
     void showVideoContextMenu(QPoint point);
     // bar
@@ -99,6 +100,11 @@ private:
     QTimer *workaroundTimer;
     Video *skippedVideo;
 
+#ifdef APP_DEMO
+    void demoExpired();
+    int tracksPlayed;
+#endif
+
 };
 
 #endif // __MEDIAVIEW_H__
